/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor.greenseeker;

import java.util.Arrays;
import java.util.List;
import nl.cloudfarming.client.logging.AppLogFactory;
import nl.cloudfarming.client.logging.AppLogger;
import nl.cloudfarming.client.sensor.SensorProcessorProvider;
import nl.cloudfarming.client.sensor.SensorUtil;
import nl.cloudfarming.client.util.FilePickerUtil;
import org.openide.filesystems.FileObject;
import org.openide.util.NbBundle;
import org.openide.util.lookup.ServiceProvider;

/**
 * Processor for greenseeker data
 *
 * @author Gerben Feenstra
 */
@ServiceProvider(service = SensorProcessorProvider.class)
public class GreenseekerProcessorProvider implements SensorProcessorProvider {

    private static final AppLogger LOG = AppLogFactory.getLogger(GreenseekerProcessorProvider.class);
    private final String formatDescription = NbBundle.getMessage(this.getClass(), "sensor.greenseeker.fileprocessor.formatdescription", FilePickerUtil.getFileFilterTypeString(getSupportedExtentions()));

    // Is there a better place then here? Header length is also specified in GreenseekerFileProcessor
    private static final int HEADER_LENGTH_NORMAL = 480;
    private static final int HEADER_LENGTH_BORNE = 672;

    @Override
    public List<String> getSupportedExtentions() {
        return Arrays.asList(new String[]{".dbf"});
    }

    @Override
    public boolean isSupported(FileObject sensorFile) {
        String fileExtension = sensorFile.getName().substring(sensorFile.getName().lastIndexOf("."));

        // 1: Check extension
        if(!getSupportedExtentions().contains(fileExtension)){
            return false;
        }
        // 2: Check header
        if(!SensorUtil.hasValidHeader(sensorFile, GreenseekerFileDescriptionBorne.values()) &&
        !SensorUtil.hasValidHeader(sensorFile, GreenseekerFileDescriptionNormal.values())){
            return false;
        }

        return true;
    }

    @Override
    public String getFormatDescription() {
        return this.formatDescription;
    }

    /*
     * Provide the right GreenseekerFileProcessor instance 
     * 
     * TODO: Exception handling
     */
    @Override 
    //FIXME
    public GreenseekerFileProcessor getProcessor(FileObject sensorFile) { 
        if(SensorUtil.hasValidHeader(sensorFile, GreenseekerFileDescriptionBorne.values())){
            //return new GreenseekerFileProcessorBorne(sensorFile);
        }
        else if(SensorUtil.hasValidHeader(sensorFile, GreenseekerFileDescriptionNormal.values())){
            //return new GreenseekerFileProcessorNormal(sensorFile);
        }
        return null;
    }
}
